# Changelog

## v0.2.4 (2025-05-23)

## v0.2.3 (2025-05-23)

### Fix

- add groups while template rendering

## v0.2.2 (2024-10-25)

### Fix

- excape pipe symbol in the markdown table
- will create the file correctly when only pass the filename

## v0.2.1 (2023-09-20)

### Fix

- better error message while pre-commit
- swallow doxygen traceback, print stderr with color, if not windows

## v0.2.0 (2023-09-18)

### Feat

- Support only single-markdown file, remove other markdown types

### Fix

- add extra blank lines before list items
- spacing between ref and paras
- add extra line between details and variables if variable exists
- support list in details

## v0.1.0 (2023-08-10)
